==> ejc-settlementmanage-impl-3.0.0-20221031.103951-96-sources.jar: com/ejianc/business/settlementmanage/vo/EventListdetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 影响总包结算的关键事项清单子表-影响总包结算原因及处理人
 * 
 * @author generator
 * 
 */
public class EventListdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String settlementReason; // 影响总包结算的原因
    private java.lang.String measures; // 措施
    private java.lang.String responsibilities; // 工作组
    private java.lang.String regionalCompany; // 区域公司
    private java.lang.String branchOffice; // 分公司
    private java.lang.String projectName; // 项目
    private java.util.Date timePoint; // 时间节点
    private java.lang.String development; // 进展情况(按周汇报)
    private java.lang.String matterType; // 事项类型

    public String getMatterType() {
        return matterType;
    }

    public void setMatterType(String matterType) {
        this.matterType = matterType;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 影响总包结算的原因
     */
    public java.lang.String getSettlementReason() {
        return settlementReason;
    }

    /**
     * 影响总包结算的原因
     */
    public void setSettlementReason(java.lang.String settlementReason) {
        this.settlementReason = settlementReason;
    }
    /**
     * 措施
     */
    public java.lang.String getMeasures() {
        return measures;
    }

    /**
     * 措施
     */
    public void setMeasures(java.lang.String measures) {
        this.measures = measures;
    }
    /**
     * 工作组
     */
    public java.lang.String getResponsibilities() {
        return responsibilities;
    }

    /**
     * 工作组
     */
    public void setResponsibilities(java.lang.String responsibilities) {
        this.responsibilities = responsibilities;
    }
    /**
     * 区域公司
     */
    public java.lang.String getRegionalCompany() {
        return regionalCompany;
    }

    /**
     * 区域公司
     */
    public void setRegionalCompany(java.lang.String regionalCompany) {
        this.regionalCompany = regionalCompany;
    }
    /**
     * 分公司
     */
    public java.lang.String getBranchOffice() {
        return branchOffice;
    }

    /**
     * 分公司
     */
    public void setBranchOffice(java.lang.String branchOffice) {
        this.branchOffice = branchOffice;
    }
    /**
     * 项目
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 时间节点
     */
    public java.util.Date getTimePoint() {
        return timePoint;
    }

    /**
     * 时间节点
     */
    public void setTimePoint(java.util.Date timePoint) {
        this.timePoint = timePoint;
    }
    /**
     * 进展情况(按周汇报)
     */
    public java.lang.String getDevelopment() {
        return development;
    }

    /**
     * 进展情况(按周汇报)
     */
    public void setDevelopment(java.lang.String development) {
        this.development = development;
    }
    
}

==> ejc-settlementmanage-impl-3.0.0-20251027.062237-321-sources.jar: com/ejianc/business/settlementmanage/vo/EventListdetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 影响总包结算的关键事项清单子表-影响总包结算原因及处理人
 *
 * @author generator
 *
 */
public class EventListdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String settlementReason; // 影响总包结算的原因
    private java.lang.String measures; // 措施
    private java.lang.String responsibilities; // 工作组
    private java.lang.String regionalCompany; // 区域公司
    private java.lang.String branchOffice; // 分公司
    private java.lang.String projectName; // 项目
    private java.util.Date timePoint; // 时间节点
    private java.lang.String development; // 进展情况(按周汇报)
    private java.lang.String matterType; // 事项类型
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date planAccomplishTime; // 计划完成时间
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date realityAccomplishTime; // 实际完成时间
    private String incompleteConditionAnalyse; // 未完成情况分析
    private Integer isFlag; // 是否能删除
    public Date getPlanAccomplishTime() {
        return planAccomplishTime;
    }

    public void setPlanAccomplishTime(Date planAccomplishTime) {
        this.planAccomplishTime = planAccomplishTime;
    }

    public Date getRealityAccomplishTime() {
        return realityAccomplishTime;
    }

    public void setRealityAccomplishTime(Date realityAccomplishTime) {
        this.realityAccomplishTime = realityAccomplishTime;
    }

    public String getIncompleteConditionAnalyse() {
        return incompleteConditionAnalyse;
    }

    public void setIncompleteConditionAnalyse(String incompleteConditionAnalyse) {
        this.incompleteConditionAnalyse = incompleteConditionAnalyse;
    }

    public String getMatterType() {
        return matterType;
    }

    public void setMatterType(String matterType) {
        this.matterType = matterType;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 影响总包结算的原因
     */
    public java.lang.String getSettlementReason() {
        return settlementReason;
    }

    /**
     * 影响总包结算的原因
     */
    public void setSettlementReason(java.lang.String settlementReason) {
        this.settlementReason = settlementReason;
    }
    /**
     * 措施
     */
    public java.lang.String getMeasures() {
        return measures;
    }

    /**
     * 措施
     */
    public void setMeasures(java.lang.String measures) {
        this.measures = measures;
    }
    /**
     * 工作组
     */
    public java.lang.String getResponsibilities() {
        return responsibilities;
    }

    /**
     * 工作组
     */
    public void setResponsibilities(java.lang.String responsibilities) {
        this.responsibilities = responsibilities;
    }
    /**
     * 区域公司
     */
    public java.lang.String getRegionalCompany() {
        return regionalCompany;
    }

    /**
     * 区域公司
     */
    public void setRegionalCompany(java.lang.String regionalCompany) {
        this.regionalCompany = regionalCompany;
    }
    /**
     * 分公司
     */
    public java.lang.String getBranchOffice() {
        return branchOffice;
    }

    /**
     * 分公司
     */
    public void setBranchOffice(java.lang.String branchOffice) {
        this.branchOffice = branchOffice;
    }
    /**
     * 项目
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 时间节点
     */
    public java.util.Date getTimePoint() {
        return timePoint;
    }

    /**
     * 时间节点
     */
    public void setTimePoint(java.util.Date timePoint) {
        this.timePoint = timePoint;
    }
    /**
     * 进展情况(按周汇报)
     */
    public java.lang.String getDevelopment() {
        return development;
    }

    /**
     * 进展情况(按周汇报)
     */
    public void setDevelopment(java.lang.String development) {
        this.development = development;
    }

    public Integer getIsFlag() {
        return isFlag;
    }

    public void setIsFlag(Integer isFlag) {
        this.isFlag = isFlag;
    }
}
